@@ -2,11 +2,13 @@
 of Curses UI and general user interaction with the app,
 """
 from .pane import Pane
-from .windows import PopupWindow
+from .windows import PopupWindow, InputPopup, SelectionPopup
 from .message_pane import MessagePane
 
 __all__ = [
     "Pane",
     "MessagePane",
-    "PopupWindow"
+    "PopupWindow",
+    "InputPopup",
+    "SelectionPopup",
 ]
